@@ -12,7 +12,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.40';
+$VERSION = '1.44';
 
 my %coordConv = (
     ValueConv    => 'Image::ExifTool::GPS::ToDegrees($val)',
@@ -38,7 +38,11 @@ my %coordConv = (
     0x0001 => {
         Name => 'GPSLatitudeRef',
         Writable => 'string',
-        Notes => 'tags 0x0001-0x0006 used for camera location according to MWG 2.0',
+        Notes => q{
+            tags 0x0001-0x0006 used for camera location according to MWG 2.0. ExifTool
+            will also accept a number when writing GPSLatitude -- positive for north
+            latitudes, or negative for south
+        },
         Count => 2,
         PrintConv => {
             # extract N/S if written from Composite:GPSLatitude
@@ -64,6 +68,10 @@ my %coordConv = (
         Name => 'GPSLongitudeRef',
         Writable => 'string',
         Count => 2,
+        Notes => q{
+            ExifTool will also accept a number when writing this tag -- positive for
+            east longitudes or negative for west
+        },
         PrintConv => {
             # extract E/W if written from Composite:GPSLongitude
             # (also allow writing from a signed number)
@@ -87,7 +95,16 @@ my %coordConv = (
     0x0005 => {
         Name => 'GPSAltitudeRef',
         Writable => 'int8u',
+        Notes => q{
+            ExifTool will also accept a signed number when writing this tag, beginning
+            with "+" for above sea level, or "-" for below
+        },
         PrintConv => {
+            OTHER => sub {
+                my ($val, $inv) = @_;
+                return undef unless $inv and $val =~ /^([-+])/;
+                return($1 eq '-' ? 1 : 0);
+            },
             0 => 'Above Sea Level',
             1 => 'Below Sea Level',
         },
@@ -112,6 +129,7 @@ my %coordConv = (
         },
         ValueConv => 'Image::ExifTool::GPS::ConvertTimeStamp($val)',
         ValueConvInv => '$val=~tr/:/ /;$val',
+        PrintConv => 'Image::ExifTool::GPS::PrintTimeStamp($val)',
         # pull time out of any format date/time string
         # (converting to UTC if a timezone is given)
         PrintConvInv => sub {
@@ -269,13 +287,13 @@ my %coordConv = (
         Name => 'GPSProcessingMethod',
         Writable => 'undef',
         Notes => 'values of "GPS", "CELLID", "WLAN" or "MANUAL" by the EXIF spec.',
-        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val,1)',
+        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val,1,$tag)',
         RawConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
     },
     0x001c => {
         Name => 'GPSAreaInformation',
         Writable => 'undef',
-        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val,1)',
+        RawConv => 'Image::ExifTool::Exif::ConvertExifText($self,$val,1,$tag)',
         RawConvInv => 'Image::ExifTool::Exif::EncodeExifText($self,$val)',
     },
     0x001d => {
@@ -316,7 +334,8 @@ my %coordConv = (
         PrintConvInv => '$val=~s/\s*m$//; $val',
         Writable => 'rational64u',
     },
-    # 0xea1c - Nokia Lumina 1020 writes this (padding) in GPS IFD - PH
+    # 0xea1c - Nokia Lumina 1020, Samsung GT-I8750, and other Windows 8
+    #          phones write this (padding) in GPS IFD - PH
 );
 
 # Composite GPS tags
@@ -391,13 +410,26 @@ sub ConvertTimeStamp($)
     $h = int($f / 3600); $f -= $h * 3600;
     $m = int($f / 60);   $f -= $m * 60;
     $s = int($f);        $f -= $s;
-    $f = int($f * 1000000 + 0.5);
+    $f = int($f * 1000000000 + 0.5);
     if ($f) {
-        ($f = sprintf(".%.6d", $f)) =~ s/0+$//;
+        ($f = sprintf(".%.9d", $f)) =~ s/0+$//;
     } else {
         $f = ''
     }
-    return sprintf("%.2d:%.2d:%.2d$f",$h,$m,$s);
+    return sprintf("%.2d:%.2d:%.2d%s",$h,$m,$s,$f);
+}
+
+#------------------------------------------------------------------------------
+# Print GPS timestamp
+# Inputs: 0) EXIF-formatted time string
+# Returns: time rounded to the nearest microsecond
+sub PrintTimeStamp($)
+{
+    my $val = shift;
+    return $val unless $val =~ s/:(\d{2}\.\d+)$//;
+    my $s = int($1 * 1000000 + 0.5) / 1000000;
+    $s = "0$s" if $s < 10;
+    return "${val}:$s";
 }
 
 #------------------------------------------------------------------------------
@@ -409,7 +441,7 @@ sub ConvertTimeStamp($)
 sub ToDMS($$;$$)
 {
     my ($et, $val, $doPrintConv, $ref) = @_;
-    my ($fmt, $num, $sign);
+    my ($fmt, @fmt, $num, $sign);
 
     if ($ref) {
         if ($val < 0) {
@@ -438,22 +470,34 @@ sub ToDMS($$;$$)
         } else {
             $fmt = "%d,%.6f$ref";   # use XMP standard format
         }
-        # count the number of format specifiers
-        $num = ($fmt =~ tr/%/%/);
+        # count (and capture) the format specifiers (max 3)
+        while ($fmt =~ /(%(%|[^%]*?[diouxXDOUeEfFgGcs]))/g) {
+            next if $1 eq '%%';
+            push @fmt, $1;
+            last if @fmt >= 3;
+        }
+        $num = scalar @fmt;
     } else {
         $num = 3;
     }
-    my ($d, $m, $s);
-    $d = $val;
+    my @c;  # coordinates (D) or (D,M) or (D,M,S)
+    $c[0] = $val;
     if ($num > 1) {
-        $d = int($d);
-        $m = ($val - $d) * 60;
+        $c[0] = int($c[0]);
+        $c[1] = ($val - $c[0]) * 60;
         if ($num > 2) {
-            $m = int($m);
-            $s = ($val - $d - $m / 60) * 3600;
+            $c[1] = int($c[1]);
+            $c[2] = ($val - $c[0] - $c[1] / 60) * 3600;
+        }
+        # handle round-off errors to ensure minutes and seconds are
+        # less than 60 (eg. convert "72 59 60.00" to "73 0 0.00")
+        $c[-1] = $doPrintConv ? sprintf($fmt[-1], $c[-1]) : ($c[-1] . '');
+        if ($c[-1] >= 60) {
+            $c[-1] -= 60;
+            ($c[-2] += 1) >= 60 and $num > 2 and $c[-2] -= 60, $c[-3] += 1;
         }
     }
-    return $doPrintConv ? sprintf($fmt, $d, $m, $s) : "$d $m $s$ref";
+    return $doPrintConv ? sprintf($fmt, @c) : "@c$ref";
 }
 
 #------------------------------------------------------------------------------
@@ -492,7 +536,7 @@ GPS (Global Positioning System) meta information in EXIF data.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
