@@ -15,7 +15,7 @@ use strict;
 use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 sub ProcessItemID($$$);
 sub ProcessLinkInfo($$$);
@@ -236,7 +236,7 @@ sub ProcessLinkInfo($$$);
     GROUPS => { 2 => 'Other' },
     PROCESS_PROC => \&ProcessItemID,
     # (can't find any documentation on these items)
-    0x0032 => { 
+    0x0032 => {
         Name => 'Item0032',
         SubDirectory => { TagTable => 'Image::ExifTool::LNK::Item0032' },
     },
@@ -599,7 +599,7 @@ sub ProcessLNK($$)
         $raf->Read($buf2, $len - 0x4c) == $len - 0x4c or return 0;
         $buff .= $buf2;
     }
-    $et->SetFileType('Windows Shortcut');
+    $et->SetFileType();
     SetByteOrder('II');
 
     my $tagTablePtr = GetTagTable('Image::ExifTool::LNK::Main');
@@ -647,7 +647,7 @@ sub ProcessLNK($$)
         next unless $flags & $mask;
         $raf->Read($buff, 2) or return 1;
         $len = unpack('v', $buff);
-        $len *= 2 if $flags & 0x80;  # characters are 2 bytes if Unicode flag is set   
+        $len *= 2 if $flags & 0x80;  # characters are 2 bytes if Unicode flag is set
         $raf->Read($buff, $len) or return 1;
         my $val;
         $val = $et->Decode($buff, 'UCS2') if $flags & 0x80;
@@ -699,7 +699,7 @@ information MS Shell Link (Windows shortcut) files.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
