@@ -21,7 +21,7 @@ use vars qw($VERSION $AUTOLOAD $lastFetched);
 use Image::ExifTool qw(:DataAccess :Utils);
 require Exporter;
 
-$VERSION = '1.38';
+$VERSION = '1.40';
 
 sub FetchObject($$$$);
 sub ExtractObject($$;$$);
@@ -754,6 +754,11 @@ sub FetchObject($$$$)
         $et->Warn("$tag object ($obj) not found at $offset");
         return undef;
     }
+    # read the first line of data for the object (skipping comments if necessary)
+    for (;;) {
+        last if $data =~ /\S/ and $data !~ /^\s*%/;
+        $raf->ReadLine($data) or $et->Warn("Error reading $tag data"), return undef;
+    }
     return ExtractObject($et, \$data, $raf, $xref);
 }
 
@@ -1242,7 +1247,7 @@ sub DecodeStream($$)
                 } elsif ($$decodeParms{EarlyChange}) {
                     $et->WarnOnce("LZWDecode EarlyChange currently not supported");
                     return 0;
-                }                    
+                }
             }
             unless (DecodeLZW(\$$dict{_stream})) {
                 $et->WarnOnce('LZW decompress error');
@@ -1491,7 +1496,7 @@ sub DecryptInit($$$)
             # make sure there is no UTF-8 flag on the password
             if ($] >= 5.006 and (eval { require Encode; Encode::is_utf8($password) } or $@)) {
                 # repack by hand if Encode isn't available
-                $password = $@ ? pack('C*',unpack('U0C*',$password)) : Encode::encode('utf8',$password);
+                $password = $@ ? pack('C*',unpack($] < 5.010000 ? 'U0C*' : 'C0C*',$password)) : Encode::encode('utf8',$password);
             }
         } else {
             return 'Incorrect password';
@@ -2007,6 +2012,12 @@ sub ProcessDict($$$$;$$)
         }
         # decode stream if necessary
         DecodeStream($et, $dict) or last;
+        if ($verbose > 2) {
+            $et->VPrint(2,"$$et{INDENT}$$et{DIR_NAME} stream data\n");
+            my %parms = ( Prefix => $$et{INDENT} );
+            $parms{MaxLen} = $verbose > 3 ? 1024 : 96 if $verbose < 5;
+            HexDump(\$$dict{_stream}, undef, %parms);
+        }
         # extract information from stream
         my %dirInfo = (
             DataPt   => \$$dict{_stream},
@@ -2297,7 +2308,7 @@ including AESV2 (AES-128) and AESV3 (AES-256).
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
