@@ -20,7 +20,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.08';
+$VERSION = '1.09';
 
 sub ProcessJpgFromRaw($$$);
 sub WriteJpgFromRaw($$$);
@@ -108,24 +108,25 @@ my %wbTypeInfo = (
     },
     # 0x18,0x19,0x1a: 0
     0x18 => { #4
-        Name => 'HighISOMultiplierRed', 
+        Name => 'HighISOMultiplierRed',
         Writable => 'int16u',
         ValueConv => '$val / 256',
         ValueConvInv => 'int($val * 256 + 0.5)',
     },
     0x19 => { #4
-        Name => 'HighISOMultiplierGreen', 
+        Name => 'HighISOMultiplierGreen',
         Writable => 'int16u',
         ValueConv => '$val / 256',
         ValueConvInv => 'int($val * 256 + 0.5)',
     },
     0x1a => { #4
-        Name => 'HighISOMultiplierBlue', 
+        Name => 'HighISOMultiplierBlue',
         Writable => 'int16u',
         ValueConv => '$val / 256',
         ValueConvInv => 'int($val * 256 + 0.5)',
     },
-    # 0x1b: [binary data]
+    # 0x1b: [binary data] (something to do with the camera ISO cababilities: int16u count N,
+    #                      followed by table of  N entries: int16u ISO, int16u[3] RGB gains - ref 4)
     0x1c => { Name => 'BlackLevelRed',   Writable => 'int16u' }, #4
     0x1d => { Name => 'BlackLevelGreen', Writable => 'int16u' }, #4
     0x1e => { Name => 'BlackLevelBlue',  Writable => 'int16u' }, #4
@@ -149,6 +150,7 @@ my %wbTypeInfo = (
     # 0x2d: 2,3
     0x2e => { #JD
         Name => 'JpgFromRaw', # (writable directory!)
+        Groups => { 2 => 'Preview' },
         Writable => 'undef',
         # protect this tag because it contains all the metadata
         Flags => [ 'Binary', 'Protected', 'NestedHtmlDump', 'BlockExtract' ],
@@ -165,6 +167,10 @@ my %wbTypeInfo = (
             ProcessProc => \&ProcessJpgFromRaw,
         },
     },
+    0x2f => { Name => 'CropTop',    Writable => 'int16u' },
+    0x30 => { Name => 'CropLeft',   Writable => 'int16u' },
+    0x31 => { Name => 'CropBottom', Writable => 'int16u' },
+    0x32 => { Name => 'CropRight',  Writable => 'int16u' },
     0x10f => {
         Name => 'Make',
         Groups => { 2 => 'Camera' },
@@ -258,6 +264,7 @@ my %wbTypeInfo = (
             Start => '$val',
         },
     },
+    # 0xffff => 'DCSHueShiftValues', #exifprobe (NC)
 );
 
 # white balance information (ref 4)
@@ -615,7 +622,7 @@ write meta information in Panasonic/Leica RAW, RW2 and RWL images.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
