@@ -16,7 +16,7 @@ use strict;
 use vars qw($VERSION $AUTOLOAD);
 use Image::ExifTool qw(:DataAccess :Utils);
 
-$VERSION = '1.36';
+$VERSION = '1.41';
 
 sub WritePS($$);
 sub ProcessPS($$;$);
@@ -77,6 +77,7 @@ sub ProcessPS($$;$);
         },
     },
     TIFFPreview => {
+        Groups => { 2 => 'Preview' },
         Binary => 1,
         Notes => q{
             not a real tag ID, but used to represent the TIFF preview extracted from DOS
@@ -217,7 +218,8 @@ sub DecodeComment($$$;$)
                 @$lines = split /$altnl/, $buff, -1;
                 # handle case of DOS newline data inside file using Unix newlines
                 @$lines = ( $$lines[0] . $$lines[1] ) if @$lines == 2 and $$lines[1] eq $/;
-                @$lines[-1] .= $/ if $/ eq "\x0d\x0a";  # add back trailing newline
+                # add back trailing DOS newline if necessary
+                @$lines ? @$lines[-1] .= $/ : push @$lines, $/ if $/ eq "\x0d\x0a";
             } else {
                 push @$lines, $buff;
             }
@@ -326,7 +328,10 @@ sub ProcessPS($$;$)
     my ($data, $dos, $endDoc, $fontTable, $comment);
 
     # allow read from data
-    $raf = new File::RandomAccess($$dirInfo{DataPt}) unless $raf;
+    unless ($raf) {
+        $raf = new File::RandomAccess($$dirInfo{DataPt});
+        $et->VerboseDir('PostScript');
+    }
 #
 # determine if this is a postscript file
 #
@@ -382,6 +387,7 @@ sub ProcessPS($$;$)
         $raf->Seek($pos, 0);
     }
     $et->SetFileType($type);
+    return 1 if $$et{OPTIONS}{FastScan} and $$et{OPTIONS}{FastScan} == 3;
 #
 # extract TIFF information from DOS header
 #
@@ -545,7 +551,7 @@ sub ProcessPS($$;$)
             next;
         } elsif ($embedded and $data =~ /^%AI12_CompressedData/) {
             # the rest of the file is compressed
-            unless (eval 'require Compress::Zlib') {
+            unless (eval { require Compress::Zlib }) {
                 $et->Warn('Install Compress::Zlib to extract compressed embedded data');
                 last;
             }
@@ -668,7 +674,7 @@ This code reads meta information from EPS (Encapsulated PostScript), PS
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
