@@ -19,7 +19,7 @@ package Image::ExifTool::Shortcuts;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.53';
+$VERSION = '1.57';
 
 # this is a special table used to define command-line shortcuts
 # (documentation Notes may be added for these via %shortcutNotes in BuildTagLookup.pm)
@@ -149,6 +149,7 @@ $VERSION = '1.53';
         'MakerNoteMinolta',
         'MakerNoteMinolta2',
         'MakerNoteMinolta3',
+        'MakerNoteMotorola',
         'MakerNoteNikon',
         'MakerNoteNikon2',
         'MakerNoteNikon3',
@@ -161,6 +162,9 @@ $VERSION = '1.53';
         'MakerNoteLeica4',
         'MakerNoteLeica5',
         'MakerNoteLeica6',
+        'MakerNoteLeica7',
+        'MakerNoteLeica8',
+        'MakerNoteLeica9',
         'MakerNotePanasonic',
         'MakerNotePanasonic2',
         'MakerNotePentax',
@@ -224,7 +228,7 @@ $VERSION = '1.53';
         'IFD0:Artist',
         'IFD0:Copyright',
         # other TIFF tags
-        'IFD0:Rating', 
+        'IFD0:Rating',
         'IFD0:RatingPercent',
         'IFD0:DNGLensInfo',
         'IFD0:PanasonicTitle',
@@ -321,7 +325,7 @@ name prefix.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
