@@ -16,7 +16,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Sigma;
 
-$VERSION = '1.22';
+$VERSION = '1.24';
 
 sub ProcessX3FHeader($$$);
 sub ProcessX3FDirectory($$$);
@@ -45,16 +45,19 @@ sub ProcessX3FProperties($$$);
     },
     IMAG => {
         Name => 'PreviewImage',
+        Groups => { 2 => 'Preview' },
         Binary => 1,
     },
     IMA2 => [
         {
             Name => 'PreviewImage',
             Condition => 'not $$self{IsJpgFromRaw}',
+            Groups => { 2 => 'Preview' },
             Binary => 1,
         },
         {
             Name => 'JpgFromRaw',
+            Groups => { 2 => 'Preview' },
             Binary => 1,
         },
     ]
@@ -295,7 +298,7 @@ sub ProcessX3FHeader($$$)
         my $verbose = $et->Options('Verbose');
         if ($verbose) {
             $et->VerboseDir('X3F HeaderExt', 32);
-            Image::ExifTool::HexDump($dataPt, undef,
+            HexDump($dataPt, undef,
                 MaxLen => $verbose > 3 ? 1024 : 96,
                 Out    => $et->Options('TextOut'),
                 Prefix => $$et{INDENT},
@@ -570,7 +573,7 @@ sub ProcessX3F($$)
     # check version number
     my $ver = unpack('x4V',$buff);
     $ver = ($ver >> 16) . '.' . ($ver & 0xffff);
-    if ($ver > 4) {
+    if ($ver > 5) {
         &$warn($et, "Untested X3F version ($ver). Please submit sample for testing", 1);
     }
     # read version 2.1/2.2/2.3 extended header
@@ -643,7 +646,7 @@ Sigma and Foveon X3F images.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
