@@ -15,7 +15,7 @@ use vars qw($VERSION @ISA);
 use Image::ExifTool qw(:Utils :Vars);
 use Image::ExifTool::XMP;
 
-$VERSION = '1.25';
+$VERSION = '1.28';
 @ISA = qw(Exporter);
 
 # set this to a language code to generate Lang module with 'MISSING' entries
@@ -55,6 +55,7 @@ my %translateLang = (
     se    => 'sv',
 );
 
+my $numbersFirst = 1;   # set to -1 to sort numbers last, or 2 to put negative numbers last
 my $caseInsensitive;    # used internally by sort routine
 
 #------------------------------------------------------------------------------
@@ -87,6 +88,7 @@ sub Write(;$$%)
         $fp = \*STDOUT;
     }
     print $fp "<?xml version='1.0' encoding='UTF-8'?>\n";
+    print $fp "<!-- Generated by Image::ExifTool $Image::ExifTool::VERSION -->\n";
     print $fp "<taginfo>\n\n";
 
     # loop through all tables and save tag names to %allTags hash
@@ -103,7 +105,10 @@ sub Write(;$$%)
         if ($$table{GROUPS} and $$table{GROUPS}{0} eq 'XMP') {
             Image::ExifTool::XMP::AddFlattenedTags($table);
         }
+        $numbersFirst = 2;
+        $numbersFirst = -1 if $$table{VARS} and $$table{VARS}{ALPHA_FIRST};
         my @keys = sort NumbersFirst TagTableKeys($table);
+        $numbersFirst = 1;
         # loop throug all tag ID's in this table
         foreach $tagID (@keys) {
             my @infoArray = GetTagInfoList($table, $tagID);
@@ -243,7 +248,7 @@ PTILoop:    for ($index=0; $index<@infoArray; ++$index) {
                     if ($$conv{BITMASK}) {
                         foreach $key (keys %{$$conv{BITMASK}}) {
                             my $mask = 0x01 << $key;
-                            next if $$conv{$mask};
+                            next if not $mask or $$conv{$mask};
                             $$conv{$mask} = $$conv{BITMASK}{$key};
                         }
                     }
@@ -402,7 +407,7 @@ sub BuildLangModules($;$)
                     next;
                 }
                 my @infoArray = GetTagInfoList($table, $id);
-    
+
                 # this will fail for UserDefined tags and tags without ID's
                 @infoArray or warn("Error loading tag for $tableName ID='$id'\n"), next;
                 my ($tagInfo, $langInfo);
@@ -462,12 +467,13 @@ sub BuildLangModules($;$)
                     unless (defined $convVal) {
                         if ($$printConv{BITMASK} and $key =~ /^\d+$/) {
                             my $i;
-                            for ($i=0; $i<32; ++$i) {
-                                next unless $key == (0x01 << $i);
+                            for ($i=0; $i<64; ++$i) {
+                                my $mask = (0x01 << $i) or last;
+                                next unless $key == $mask;
                                 $convVal = $$printConv{BITMASK}{$i};
                             }
                         }
-                        warn("Missing PrintConv entry for $key") and next unless defined $convVal;
+                        warn("Missing PrintConv entry for $tableName $$tagInfo{Name} $key\n") and next unless defined $convVal;
                     }
                     if ($cap and $convVal =~ /^[a-z]/) {
                         $val = lcfirst $val;    # change back to lower case
@@ -624,7 +630,7 @@ and values.
 
 ~head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -671,16 +677,32 @@ sub LoadLangModules($;$)
 sub NumbersFirst
 {
     my $rtnVal;
-    my $bNum = ($b =~ /^-?[0-9]+(\.\d*)?$/);
-    if ($a =~ /^-?[0-9]+(\.\d*)?$/) {
-        $rtnVal = ($bNum ? $a <=> $b : -1);
-    } elsif ($bNum) {
-        $rtnVal = 1;
+    my ($bNum, $bDec);
+    ($bNum, $bDec) = ($1, $3) if $b =~ /^(-?[0-9]+)(\.(\d*))?$/;
+    if ($a =~ /^(-?[0-9]+)(\.(\d*))?$/) {
+        if (defined $bNum) {
+            $bNum += 1e9 if $numbersFirst == 2 and $bNum < 0;
+            my $aInt = $1;
+            $aInt += 1e9 if $numbersFirst == 2 and $aInt < 0;
+            # compare integer part as a number
+            $rtnVal = $aInt <=> $bNum;
+            unless ($rtnVal) {
+                my $aDec = $3 || 0;
+                $bDec or $bDec = 0;
+                # compare decimal part as an integer too
+                # (so that "1.10" comes after "1.9")
+                $rtnVal = $aDec <=> $bDec;
+            }
+        } else {
+            $rtnVal = -$numbersFirst;
+        }
+    } elsif (defined $bNum) {
+        $rtnVal = $numbersFirst;
     } else {
         my ($a2, $b2) = ($a, $b);
         # expand numbers to 3 digits (with restrictions to avoid messing up ascii-hex tags)
-        $a2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $a2 =~ /^(APP)?[.0-9 ]*$/ and length($a2)<16;
-        $b2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $b2 =~ /^(APP)?[.0-9 ]*$/ and length($b2)<16;
+        $a2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $a2 =~ /^(APP|DMC-\w+ )?[.0-9 ]*$/ and length($a2)<16;
+        $b2 =~ s/(\d+)/sprintf("%.3d",$1)/eg if $b2 =~ /^(APP|DMC-\w+ )?[.0-9 ]*$/ and length($b2)<16;
         $caseInsensitive and $rtnVal = (lc($a2) cmp lc($b2));
         $rtnVal or $rtnVal = ($a2 cmp $b2);
     }
@@ -792,7 +814,7 @@ Number of modules updated, or negative on error.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
